@@ -1,44 +1,33 @@
 import logging
-from datetime import date
+from datetime import date, datetime
+from decimal import Decimal
 
 from satcfdi import Signer
-from satcfdi.create.cfd import cfdi40
 
 from satdigitalinvoice.file_data_managers import ClientsManager, FacturasManager, ConfigManager
 from satdigitalinvoice.gui_functions import generate_ingresos, periodo_desc
+from satdigitalinvoice.utils import find_best_match
 
 csd_signer = Signer.load(
     certificate=open('csd/cacx7605101p8.cer', 'rb').read(),
     key=open('csd/cacx7605101p8.key', 'rb').read(),
     password=open('csd/cacx7605101p8.txt', 'rb').read(),
 )
-
-emisor = {
-    "Emisor": cfdi40.Emisor(
-        rfc=csd_signer.rfc,
-        nombre=csd_signer.legal_name,
-        regimen_fiscal="601",
-    ),
-    "LugarExpedicion": "12345",
-}
-
+ym_date = datetime(year=2023, month=4, day=1)
 clients = ClientsManager()
 
 
 def test_generar_ingresos(caplog):
     caplog.set_level(logging.INFO)
-
-    facturas = FacturasManager()["Facturas"]
+    config = ConfigManager()
+    facturas = FacturasManager(ym_date)["Facturas"]
 
     facturas = generate_ingresos(
-        config=ConfigManager(),
+        serie=config["serie"],
+        folio=1000,
         clients=clients,
         facturas=facturas,
-        values={
-            'inicio': '1',
-            'final': '',
-            'periodo': '2023-04'
-        },
+        ym_date=date(year=2023, month=4, day=1),
         csd_signer=csd_signer,
     )
 
@@ -48,18 +37,16 @@ def test_generar_ingresos(caplog):
 
 def test_generar_ingresos_error(caplog):
     caplog.set_level(logging.INFO)
-    facturas = FacturasManager()["FacturasIncorrectas"]
+    config = ConfigManager()
+    facturas = FacturasManager(ym_date)["FacturasIncorrectas"]
     print(len(facturas))
 
     ingresos = generate_ingresos(
-        config=ConfigManager(),
+        serie=config["serie"],
+        folio=1000,
         clients=clients,
         facturas=facturas,
-        values={
-            'inicio': '1',
-            'final': '',
-            'periodo': '2023-04'
-        },
+        ym_date=date(year=2023, month=4, day=1),
         csd_signer=csd_signer,
     )
 
@@ -70,18 +57,16 @@ def test_generar_ingresos_error(caplog):
 
 def test_generar_ingresos_error2(caplog):
     caplog.set_level(logging.INFO)
-    facturas = FacturasManager()["FacturasIncorrectas2"]
+    config = ConfigManager()
+    facturas = FacturasManager(ym_date)["FacturasIncorrectas2"]
     print(len(facturas))
 
     ingresos = generate_ingresos(
-        config=ConfigManager(),
+        serie=config["serie"],
+        folio=1000,
         clients=ClientsManager(),
         facturas=facturas,
-        values={
-            'inicio': '1',
-            'final': '',
-            'periodo': '2023-04'
-        },
+        ym_date=date(year=2023, month=4, day=1),
         csd_signer=csd_signer,
     )
 
@@ -104,3 +89,25 @@ def test_periodo_desc():
     assert periodo_desc(date(year=2021, month=12, day=1), 'Cuatrimestral.8') == 'MES DE DICIEMBRE DEL 2021 AL MES DE MARZO DEL 2022'
     assert periodo_desc(date(year=2021, month=12, day=1), 'Semestral.6') == 'MES DE DICIEMBRE DEL 2021 AL MES DE MAYO DEL 2022'
     assert periodo_desc(date(year=2021, month=12, day=1), 'Anual.12') == 'MES DE DICIEMBRE DEL 2021 AL MES DE NOVIEMBRE DEL 2022'
+
+
+def test_find_best_match():
+    casesA = {
+        '2022-12': Decimal('20.00'),
+        '2023-12': Decimal('30.00'),
+        '2024-12': Decimal('40.00'),
+        '2025-12': None,
+    }
+    casesB = {
+        '2025-12': None,
+        '2024-12': Decimal('40.00'),
+        '2023-12': Decimal('30.00'),
+        '2022-12': Decimal('20.00'),
+    }
+
+    for cases in (casesA, casesB):
+        assert find_best_match(cases, datetime(2022, 4, 5))[1] is None
+        assert find_best_match(cases, datetime(2023, 4, 5))[1] == Decimal('20.00')
+        assert find_best_match(cases, datetime(2024, 4, 5))[1] == Decimal('30.00')
+        assert find_best_match(cases, datetime(2025, 4, 5))[1] == Decimal('40.00')
+        assert find_best_match(cases, datetime(2026, 4, 5))[1] is None
